#!/bin/bash
# This is a quick and dirty but still quite awesome script to switch ALSA
# output on the fly. It copies valid config files to enable output
# devices on demand.
# As of version 0.1 two configs are provided:
#
# 1. BT output -> .asoundrc_bt
# 2. HW output -> .asoundrc_hw
#
# Before any sound is being played ALSA parses the config files, so
# there's NO need to restart your system after you used this script.
#
# Please set ALSAFILES_PATH correctly!

ALSAFILES_PATH=~/alsafiles/

if [[ $# = 0 ]]; then
        echo "No options parsed. Try "$0" --help"
fi

while [[ $# > 0 ]]
do
key="$1"

case $key in
	-o|--output)
	OUTPUT="$2"
	shift
	if [[ ${OUTPUT} = "bt" ]];then
		echo "Switching audio output to:"
		echo ${OUTPUT}
		echo "using config files from:"
		echo ${ALSAFILES_PATH}
		rm -v ~/.asoundrc
                cp -v ${ALSAFILES_PATH}.asoundrc_bt ~/.asoundrc
	elif [[ ${OUTPUT} = "hw" ]];then
                echo "Switching audio output to:"
                echo ${OUTPUT}
                echo "using config files from:"
                echo ${ALSAFILES_PATH}
		rm -v ~/.asoundrc
		cp -v ${ALSAFILES_PATH}.asoundrc_hw ~/.asoundrc
	else
		echo "Unsupported output mode parsed. Exiting."
	fi
	;;
	-h|--help)
	echo
	echo "KickAss Pandora Audio Switch v0.1"
	echo "------------------------"
	echo "Usage:"
	echo "-h|--help 	Display this message."
	echo "-o|--output	Set audio outout mode."
	echo "			So far bt and hw are supported."
	echo
	echo "Example: ./audioswitch.sh -o bt"
	echo
	;;
	*)
	echo "Unknown option parsed. Exiting."
	;;
esac
shift
done
